@@ -7,7 +7,7 @@ Density function of Generalized Log-gamma distribution
 import math
 import numpy as np
 
-def dglg(x, location = 0, scale = 1, shape = 1):
+def pdf(x, location = 0, scale = 1, shape = 1):
     x = np.array(x)
     if abs(shape) < 0.1:
         if shape > 0: 
@@ -24,4 +24,4 @@ def dglg(x, location = 0, scale = 1, shape = 1):
     output = cl_shape*output/scale
     return output
 
-# print(dglg(x = [0,1,2]))
\ No newline at end of file
+#print(pdf(x = [0,1,2]))
\ No newline at end of file
